@@ -1,7 +1,7 @@
-context("utility functions")
+testthat::context("utility functions")
 
-test_that("subsetting in ltable works and ltable has no side effects", {
-  popEpi:::skip_on_cran_and_ci()
+testthat::test_that("subsetting in ltable works and ltable has no side effects", {
+  popEpi:::skip_normally()
   
   sr <- popEpi::sire[1:100, ]
   set.seed(1L)
@@ -15,16 +15,16 @@ test_that("subsetting in ltable works and ltable has no side effects", {
   lt2 <- ltable(sr, by = "sex", subset = sex == 1, na.rm = TRUE)
   lt3 <- ltable(sr, by = "sex", na.rm = TRUE)
   
-  expect_equal(lt3$obs, c(lt1[1, ]$obs, lt2[2, ]$obs))
-  expect_true(all.equal(sr, old_sr))
+  testthat::expect_equal(lt3$obs, c(lt1[1, ]$obs, lt2[2, ]$obs))
+  testthat::expect_true(all.equal(sr, old_sr))
   
 })
 
 
 
-test_that("ltable works with NA values", {
+testthat::test_that("ltable works with NA values", {
   
-  popEpi:::skip_on_cran_and_ci()
+  popEpi:::skip_normally()
   
   sr <- setDT(popEpi::sire[1:100, ])
   set.seed(1L)
@@ -34,13 +34,13 @@ test_that("ltable works with NA values", {
   lt1 <- ltable(sr, by = "sex", na.rm = FALSE)
   lt2 <- ltable(sr, by = "sex", na.rm = TRUE)
   
-  expect_equal(lt1[!is.na(sex),], lt2)
+  testthat::expect_equal(lt1[!is.na(sex),], lt2)
   
 })
 
 
 
-test_that("evalPopArg produces intended results",{
+testthat::test_that("evalPopArg produces intended results",{
   set.seed(1L)
   dt <- data.table(a = rbinom(10, 100, 0.25), b = 1:2, c = 1:5)
   
@@ -59,8 +59,8 @@ test_that("evalPopArg produces intended results",{
   ## name string
   t2 <- tf(arg="b")
   
-  expect_equal(t1$sum, c(127, 131))
-  expect_equal(t1, t2)
+  testthat::expect_equal(t1$sum, c(127, 131))
+  testthat::expect_equal(t1, t2)
   
   ## list of symbols / expressions
   t3 <- tf(arg=list(b, c))
@@ -72,20 +72,20 @@ test_that("evalPopArg produces intended results",{
   byVars <- c("b", "c")
   t5 <- tf(arg=byVars)
   
-  expect_equal(t4$sum, c(22,24,26,31,21, 31,32,27,26,18))
-  expect_equal(t4, t3)
-  expect_equal(t4, t5)
+  testthat::expect_equal(t4$sum, c(22,24,26,31,21, 31,32,27,26,18))
+  testthat::expect_equal(t4, t3)
+  testthat::expect_equal(t4, t5)
   
   ## list of symbols / expressions
   t6 <- tf(arg=list(var1 = b,c, cut(c,3)))
-  expect_equal(names(t6), c("var1", "c", "cut", "sum"))
+  testthat::expect_equal(names(t6), c("var1", "c", "cut", "sum"))
   
   
   ## NULL object
   byVars <- NULL
   t7 <- tf(arg=byVars)
   t8 <- tf(arg=NULL)
-  expect_equal(t7, t8)
+  testthat::expect_equal(t7, t8)
   
   ## a list of predetermined values
   byList <- as.list(dt[, list(b, var1 = c)])
@@ -99,27 +99,27 @@ test_that("evalPopArg produces intended results",{
   byList <- list(var1 = dt$b, dt$c)
   t11<- tf(arg=byList)
   
-  expect_equal(t9$sum, t10$sum)
-  expect_equal(t10$sum, t11$sum)
-  expect_equal(names(t11), c("var1", "BV2", "sum"))
+  testthat::expect_equal(t9$sum, t10$sum)
+  testthat::expect_equal(t10$sum, t11$sum)
+  testthat::expect_equal(names(t11), c("var1", "BV2", "sum"))
   
   
   t12 <- tf(arg=list(V0=dt$b, dt$c))
   byList <- list(V0 = dt$b, dt$c)
   t13 <- tf(arg=byList)
-  expect_equal(t12, t13)
+  testthat::expect_equal(t12, t13)
   
   ## pre-substituted list
   bl <- substitute(byList)
   t14 <- tf(arg = bl)
-  expect_equal(t12, t14)
+  testthat::expect_equal(t12, t14)
   
   ## pre-substituted vector of names
   nv <- c("a", "b")
   nvs <- substitute(nv)
   t15a <- tf(arg = nv)
   t15b <- tf(arg = nvs)
-  expect_equal(t15a, t15b)
+  testthat::expect_equal(t15a, t15b)
   
   ## nested functions
   tf2 <- function(a, x = dt) {
@@ -130,12 +130,12 @@ test_that("evalPopArg produces intended results",{
   nvs <- substitute(nv)
   t15a <- tf2(a = nv)
   t15b <- tf2(a = nvs)
-  expect_equal(t15a, t15b)
+  testthat::expect_equal(t15a, t15b)
 })
 
 
-test_that("cutLowMerge merges succesfully what is intended", {
-  popEpi:::skip_on_cran_and_ci()
+testthat::test_that("cutLowMerge merges succesfully what is intended", {
+  popEpi:::skip_normally()
   all_names_present(popEpi::popmort, c("sex", "year", "agegroup", "haz"))
   all_names_present(popEpi::sire, c("sex", "bi_date", "dg_date", "ex_date", "status"))
   
@@ -162,8 +162,8 @@ test_that("cutLowMerge merges succesfully what is intended", {
   
   sr4 <- lexpand(sr, birth = bi_date, entry = dg_date, exit = ex_date,
                  status = status, fot = seq(0, 5, 1/12), pophaz = pm, pp = FALSE)
-  expect_equal(sr1, sr3, check.attributes = FALSE)
-  expect_equal(sr2$haz*1e5L, sr4$pop.haz*1e5L, check.attributes = FALSE)
+  testthat::expect_equal(sr1, sr3, check.attributes = FALSE)
+  testthat::expect_equal(sr2$haz*1e5L, sr4$pop.haz*1e5L, check.attributes = FALSE)
   
   sr1[, year := popEpi:::cutLow(year, breaks = sort(unique(pm$year)))]
   sr1[, agegroup := popEpi:::cutLow(agegroup, breaks = sort(unique(pm$agegroup)))]
@@ -172,11 +172,11 @@ test_that("cutLowMerge merges succesfully what is intended", {
   setDT(sr5)
   setkey(sr5, lex.id, fot)
   
-  expect_equal(sr4$haz*1e5L, sr5$pop.haz*1e5L, check.attributes = FALSE)
+  testthat::expect_equal(sr4$haz*1e5L, sr5$pop.haz*1e5L, check.attributes = FALSE)
 })
 
-test_that("detectEvents works as intended", {
-  popEpi:::skip_on_cran_and_ci()
+testthat::test_that("detectEvents works as intended", {
+  popEpi:::skip_normally()
   x <- sire[dg_date<ex_date,]
   x <- lexpand(x, birth = bi_date, entry = dg_date, exit = ex_date,
                status = status %in% 1:2, pophaz = data.table(popEpi::popmort),
@@ -194,11 +194,11 @@ test_that("detectEvents works as intended", {
   x[lex.Cst != lex.Xst, alt.event := 1L]
   x[fot+lex.dur == 5L, alt.event := 0L]
   
-  expect_equal(x$event, x$alt.event)
+  testthat::expect_equal(x$event, x$alt.event)
   
 })
 
-test_that("comp_pp_weighted_figures produces intended results", {
+testthat::test_that("comp_pp_weighted_figures produces intended results", {
   set.seed(1L)
   x <- sire[dg_date < ex_date,][sample(x = .N, size = 5L, replace = FALSE),]
   x <- lexpand(x, birth = bi_date, entry = dg_date, exit = ex_date,
@@ -209,16 +209,16 @@ test_that("comp_pp_weighted_figures produces intended results", {
   l <- comp_pp_weighted_figures(lex = x, haz = "pop.haz", pp = "pp", event.ind = "event", by = "lex.id")
   x[, names(l) := l]
   
-  expect_equal(x[event %in% 1:2, pp], x[event %in% 1:2, from0to0.pp + from0to1.pp])
-  expect_equal(x[event %in% 1:2, sum(pp)], x[, sum(from0to0.pp + from0to1.pp)])
-  expect_equal(x[, lex.dur*pp], x$ptime.pp)
-  expect_equal(x[, lex.dur*pp*pop.haz], x$d.exp.pp)
-  expect_equal(x[event == 1L, pp^2], x[event == 1L,]$from0to1.pp.2)
+  testthat::expect_equal(x[event %in% 1:2, pp], x[event %in% 1:2, from0to0.pp + from0to1.pp])
+  testthat::expect_equal(x[event %in% 1:2, sum(pp)], x[, sum(from0to0.pp + from0to1.pp)])
+  testthat::expect_equal(x[, lex.dur*pp], x$ptime.pp)
+  testthat::expect_equal(x[, lex.dur*pp*pop.haz], x$d.exp.pp)
+  testthat::expect_equal(x[event == 1L, pp^2], x[event == 1L,]$from0to1.pp.2)
   
 })
 
 
-test_that("evalPopFormula & usePopFormula output is stable", {
+testthat::test_that("evalPopFormula & usePopFormula output is stable", {
   evalPopFormula <- popEpi:::evalPopFormula
   usePopFormula <- popEpi:::usePopFormula
   
@@ -250,21 +250,21 @@ test_that("evalPopFormula & usePopFormula output is stable", {
   r1a <- evalPopFormula(f1a, data = x, enclos = TF, Surv.response = TRUE)
   r1b <- evalPopFormula(f1b, data = x, enclos = TF, Surv.response = TRUE)
   setattr(r1a, "formula", attr(r1b, "formula"))
-  expect_equal(r1a, r1b)
-  expect_equal(data.table(r1a), res[, list(time, status)])
+  testthat::expect_equal(r1a, r1b)
+  testthat::expect_equal(data.table(r1a), res[, list(time, status)])
   
   r5 <- evalPopFormula(f5, data = x, enclos = parent.frame(1L), Surv.response = FALSE)
   r6 <- evalPopFormula(f6, data = x, enclos = parent.frame(1L), Surv.response = FALSE)
-  expect_equal(r5$lex.Xst, c(1,1,0,1,1))
-  expect_equal(data.table(r6), res[, list(lex.Xst, sex)])
+  testthat::expect_equal(r5$lex.Xst, c(1,1,0,1,1))
+  testthat::expect_equal(data.table(r6), res[, list(lex.Xst, sex)])
   
   ## model-type naming of columns
   r9 <- evalPopFormula(f9, data = x, enclos = parent.frame(1L), Surv.response = FALSE)
-  expect_equal(data.table(r9), res[, list(lex.Xst, "factor(sex)" = factor(sex))])
+  testthat::expect_equal(data.table(r9), res[, list(lex.Xst, "factor(sex)" = factor(sex))])
   
   ## multiple variables, model-type naming of columns with adjust
   r3 <- evalPopFormula(f3, data = x, enclos = parent.frame(1L), Surv.response = TRUE)
-  expect_equivalent(r3, res[, .SD, .SDcols = names(r3)])
+  testthat::expect_equivalent(r3, res[, .SD, .SDcols = names(r3)])
   
   
   #### only the survival time scale as response
@@ -274,32 +274,32 @@ test_that("evalPopFormula & usePopFormula output is stable", {
   fd <- fot ~ adjust(factor(sex + 1))
   
   ra <- evalPopFormula(fa, data = x, enclos = TF, Surv.response = "either")
-  expect_equivalent(ra, x[, .(fot, lex.Xst)])
+  testthat::expect_equivalent(ra, x[, .(fot, lex.Xst)])
   rb <- evalPopFormula(fb, data = x, enclos = parent.frame(1L), Surv.response = FALSE)
-  expect_equivalent(rb, x[, .(fot, sex)])
+  testthat::expect_equivalent(rb, x[, .(fot, sex)])
   rc <- evalPopFormula(fc, data = x, enclos = parent.frame(1L), Surv.response = "either")
-  expect_equivalent(rc, x[, .(fot, lex.Xst, sex, factor(sex + 1))])
+  testthat::expect_equivalent(rc, x[, .(fot, lex.Xst, sex, factor(sex + 1))])
   rd <- evalPopFormula(fd, data = x, enclos = TF, Surv.response = FALSE)
-  expect_equivalent(rd, x[, .(fot, factor(sex + 1))])
+  testthat::expect_equivalent(rd, x[, .(fot, factor(sex + 1))])
   
   ## usePopFormula
   
   r3 <- usePopFormula(f3, data = x, enclos = parent.frame(2L), Surv.response = TRUE)
-  expect_equivalent(r3, 
+  testthat::expect_equivalent(r3, 
                     list(y = res[, list(time, status)], 
                          print = res[, list(sex)], 
                          adjust = res[, "factor(sex + 1)", with = FALSE],
                          formula = f3) 
   )
   r4 <- usePopFormula(f4, data = x, enclos = parent.frame(2L), Surv.response = TRUE)
-  expect_equivalent(r4, 
+  testthat::expect_equivalent(r4, 
                     list(y = res[, list(time, status)], 
                          print = NULL, 
                          adjust = res[, "factor(sex + 1)", with = FALSE],
                          formula = f4) 
   )
   r6 <- usePopFormula(f6, data = x, enclos = parent.frame(2L), Surv.response = FALSE)
-  expect_equivalent(r6, 
+  testthat::expect_equivalent(r6, 
                     list(y = res[, list(lex.Xst)], 
                          print = res[, list(sex)], 
                          adjust = NULL,
@@ -307,14 +307,14 @@ test_that("evalPopFormula & usePopFormula output is stable", {
   )
   
   r7 <- usePopFormula(f7, data = x, enclos = parent.frame(2L), Surv.response = FALSE)
-  expect_equivalent(r7, 
+  testthat::expect_equivalent(r7, 
                     list(y = res[, list(lex.Xst)], 
                          print = res[, list(sex)], 
                          adjust = res[, "factor(sex + 1)", with = FALSE],
                          formula = f7) 
   )
   r8 <- usePopFormula(f8, data = x, enclos = parent.frame(2L), Surv.response = FALSE)
-  expect_equivalent(r8, 
+  testthat::expect_equivalent(r8, 
                     list(y = res[, list(lex.Xst)], 
                          print = NULL, 
                          adjust = res[, "factor(sex + 1)", with = FALSE],
@@ -322,18 +322,18 @@ test_that("evalPopFormula & usePopFormula output is stable", {
   )
   r9 <- usePopFormula(lex.Xst ~ sex, data = x, adjust = quote(factor(sex + 1)),
                       enclos = parent.frame(2L), Surv.response = FALSE) 
-  expect_equivalent(r9, 
+  testthat::expect_equivalent(r9, 
                     list(y = res[, list(lex.Xst)], 
                          print = res[, list(sex)], 
                          adjust = res[, "factor(sex + 1)", with = FALSE],
                          formula = lex.Xst ~ sex)
   )
-  expect_equal(lapply(r9, names), list(y = "lex.Xst", print = "sex", adjust = "factor(sex + 1)", formula = NULL))
+  testthat::expect_equal(lapply(r9, names), list(y = "lex.Xst", print = "sex", adjust = "factor(sex + 1)", formula = NULL))
   
   r9 <- usePopFormula(lex.Xst ~ as.numeric(sex), data = x, adjust = quote(list(factor(sex + 1), factor(sex - 1))),
                       enclos = parent.frame(2L), Surv.response = FALSE) 
   
-  expect_equal(lapply(r9, names), list(y = "lex.Xst", print = "as.numeric(sex)", 
+  testthat::expect_equal(lapply(r9, names), list(y = "lex.Xst", print = "as.numeric(sex)", 
                                        adjust = c("factor(sex + 1)", "factor(sex - 1)"), formula = NULL))
   
   
@@ -341,7 +341,7 @@ test_that("evalPopFormula & usePopFormula output is stable", {
                       adjust = quote(list(factor(sex + 1), factor(sex - 1))),
                       enclos = parent.frame(2L), Surv.response = FALSE) 
   
-  expect_equal(lapply(ra, names), 
+  testthat::expect_equal(lapply(ra, names), 
                list(y = "fot", print = NULL, 
                     adjust = c("factor(sex + 1)", "factor(sex - 1)"), 
                     formula = NULL))
@@ -350,7 +350,7 @@ test_that("evalPopFormula & usePopFormula output is stable", {
   rb <- usePopFormula(fb, data = x, 
                       adjust = quote(list(factor(sex + 1), factor(sex - 1))),
                       enclos = parent.frame(2L), Surv.response = FALSE) 
-  expect_equal(lapply(rb, names), 
+  testthat::expect_equal(lapply(rb, names), 
                list(y = "fot", print = "sex", 
                     adjust = c("factor(sex + 1)", "factor(sex - 1)"), 
                     formula = NULL))
@@ -358,7 +358,7 @@ test_that("evalPopFormula & usePopFormula output is stable", {
   rc <- usePopFormula(fc, data = x, 
                       adjust = NULL,
                       enclos = parent.frame(2L), Surv.response = "either") 
-  expect_equal(lapply(rc, names), 
+  testthat::expect_equal(lapply(rc, names), 
                list(y = c("time", "status"), print = "sex", 
                     adjust = "factor(sex + 1)", 
                     formula = NULL))
@@ -366,7 +366,7 @@ test_that("evalPopFormula & usePopFormula output is stable", {
   rd <- usePopFormula(fd, data = x, 
                       adjust = NULL,
                       enclos = parent.frame(2L), Surv.response = FALSE) 
-  expect_equal(lapply(rd, names), 
+  testthat::expect_equal(lapply(rd, names), 
                list(y = "fot", print = NULL, 
                     adjust = "factor(sex + 1)", 
                     formula = NULL))
@@ -392,29 +392,29 @@ test_that("evalPopFormula & usePopFormula output is stable", {
 
 
 
-test_that("fractional years computation works", {
+testthat::test_that("fractional years computation works", {
   library("data.table")
   c <- paste0("2004-", c("01-01", "07-01", "12-31", "02-01"))
   D <- as.Date(c)
   
-  expect_equal(get.yrs(c), get.yrs(D))
+  testthat::expect_equal(get.yrs(c), get.yrs(D))
   
   yl <- 365.242199
   my <- year(D) + (yday(D) - 1L)/yl
   
-  expect_equal(as.numeric(get.yrs(D)), my)
+  testthat::expect_equal(as.numeric(get.yrs(D)), my)
   
   yl <- ifelse(is_leap_year(year(D)), 366L, 365L)
   my <- year(D) + (yday(D) - 1L)/yl
   
-  expect_equal(as.numeric(get.yrs(D, year.length = "actual")), my)
+  testthat::expect_equal(as.numeric(get.yrs(D, year.length = "actual")), my)
 })
 
 
 
 
 
-test_that("subsetDTorDF works as intended", {
+testthat::test_that("subsetDTorDF works as intended", {
   
   dt <- data.table::data.table(a = 1:5, b = 5:1)
   df <- data.frame(a = 1:5, b = 5:1)
@@ -452,11 +452,11 @@ test_that("subsetDTorDF works as intended", {
     exp_dt <- expected_dt[[i]]
     
     list(sub_dt = sub_dt, exp_dt = exp_dt, sub_df = sub_df, exp_df = exp_df)
-    expect_equal(
+    testthat::expect_equal(
       data.frame(sub_dt),
       data.frame(exp_dt)
     )
-    expect_equal(
+    testthat::expect_equal(
       sub_df,
       exp_df
     )
